%--------------------------------------------------------------------------
%                PLOT MAKER  DYNAMIC HIV ANALYSIS
%--------------------------------------------------------------------------

clear
ElementN=1510; % Totalt nummer av elementer
endT=1015; % Tid ved ananlyse slutt
ModelName1='420_A4_14GLPLOTs';
ModelName2='420_A2_14GLPLOTs';
ModelName3='420_A4_ELPLOTs';
ModelName4='420_A2_ELPLOTs';
R=14; % Rr strrelse [in]
state='WET';
ElementT='Hshear363'; % Element type
TitleLine=['Riser ',num2str(R),'" ',state,' STATE (',ElementT,') '];
K=1/1.6995; % Allowable curvature
C=0.6160;
f=69654.21961;


%--------------------------------------------------------------------------
% Ploting max curvature vs. Time    
figure
hold on 
[Y,~]=ReadGL(ElementN,endT,[ModelName1,'_y.mpf']);
[Z,t]=ReadGL(ElementN,endT,[ModelName1,'_z.mpf']);
        
% Calculating total curvature
S=zeros(size(Y));
S(:,1)=Y(:,1);
for k=1:length(t)
    S(:,k+1)=sqrt(Z(:,k+1).^2+Y(:,k+1).^2);
end

% Calculating maximum total curvatur
Cmax=max(S(1:end-10,2:end));

% Ploting max curvature vs. Time

plot(t,Cmax,'DisplayName','Amplitude 2m')
%plot([0,endT],[C,C],'--','DisplayName','Buckling curvature')
%plot([0,endT],[K,K],'--','DisplayName','Maximum allowable curvature')
title(TitleLine)
xlabel('Time [s]')
ylabel('Total maximum curvature [1/m]')
legend('Location','best')

[Y,~]=ReadGL(ElementN,endT,[ModelName2,'_y.mpf']);
[Z,t]=ReadGL(ElementN,endT,[ModelName2,'_z.mpf']);
        
% Calculating total curvature
S=zeros(size(Y));
S(:,1)=Y(:,1);
for k=1:length(t)
    S(:,k+1)=sqrt(Z(:,k+1).^2+Y(:,k+1).^2);
end

% Calculating maximum total curvatur
Cmax=max(S(1:end-10,2:end));

% Ploting max curvature vs. Time

plot(t,Cmax,'DisplayName','Amplitude 4m')
%plot([0,endT],[C,C],'--','DisplayName','Buckling curvature')
%plot([0,endT],[K,K],'--','DisplayName','Maximum allowable curvature')
title(TitleLine)
xlabel('Time [s]')
ylabel('Total maximum curvature [1/m]')
legend('Location','best')
hold off

%--------------------------------------------------------------------------

figure
M1=ReadEP([ModelName3,'_5.mpf'],6);
plot(M1(:,1),M1(:,2)*1e-3,'DisplayName','Moment about Y, A=4m')
title(TitleLine)
xlabel('Time [s]')
ylabel('Bending Moment [kNm]')
legend('Location','best')

figure
M2=ReadEP([ModelName4,'_5.mpf'],6);
plot(M2(:,1),M2(:,2)*1e-3,'DisplayName','Moment about Y, A=2m')
title(TitleLine)
xlabel('Time [s]')
ylabel('Bending Moment [kNm]')
legend('Location','best')

figure
M3=ReadEP([ModelName3,'_6.mpf'],6);
plot(M3(:,1),M3(:,2)*1e-3,'DisplayName','Moment about Z, A=4m')
title(TitleLine)
xlabel('Time [s]')
ylabel('Bending Moment [kNm]')
legend('Location','best')

figure
M4=ReadEP([ModelName4,'_6.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Moment about Z, A=2m')
title(TitleLine)
xlabel('Time [s]')
ylabel('Bending Moment [kNm]')
legend('Location','best')

%--------------------------------------------------------------------------

figure
hold on
M4=ReadEP([ModelName3,'_ten1_4.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 1, A=4m')

M4=ReadEP([ModelName3,'_ten2_4.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 2, A=4m')

M4=ReadEP([ModelName4,'_ten1_4.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 1, A=2m')

M4=ReadEP([ModelName4,'_ten2_4.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 2, A=2m')

title(TitleLine)
xlabel('Time [s]')
ylabel('Tortion Moment [kNm]')
legend('Location','best')
hold off

%--------------------------------------------------------------------------

figure
hold on
M4=ReadEP([ModelName3,'_ten1_1.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 1, A=4m')

M4=ReadEP([ModelName3,'_ten2_1.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 2, A=4m')

plot([M4(1,1),M4(end,1)],[f,f]*1e-3,'--k','DisplayName','Buckling Force')

title(TitleLine)
xlabel('Time [s]')
ylabel('Axial Force [kN]')
legend('Location','best')
hold off

figure
hold on

M4=ReadEP([ModelName4,'_ten1_1.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 1, A=2m')

M4=ReadEP([ModelName4,'_ten2_1.mpf'],6);
plot(M4(:,1),M4(:,2)*1e-3,'DisplayName','Tensile layer 2, A=2m')

plot([M4(1,1),M4(end,1)],[f,f]*1e-3,'--k','DisplayName','Buckling Force')

title(TitleLine)
xlabel('Time [s]')
ylabel('Axial Force [kN]')
legend('Location','best')

hold off






