%--------------------------------------------------------------------------
%                PLOT MAKER  DYNAMIC HIV ANALYSIS
%--------------------------------------------------------------------------

ElementN=2307; % Totalt nummer av elementer
endT=75; % Tid ved ananlyse slutt
NameModel0='R6WcomDHa';
a=[0.5,1,2,3,4]; % Amplituder [m]
u=[0.25,0.50,0.75]; % Relativ torque
R=6; % Rr strrelse [in]
state='WET';
ElementT='Compipe42'; % Element type
TitleLine=['Riser ',num2str(R),'" ',state,' STATE (',ElementT,') '];
K=1/1.6995; % Allowable curvature
C=0.6160;

% Plot Moment vs. Time
for i=1:length(u)
    
    figure
    hold on
    for j=1:length(a)
        ModelName=[NameModel0,num2str(a(j)*10),'u',num2str(u(i)*100)];
        M=ReadEP([ModelName,'M.mpf'],0);
        plot(M(:,1),M(:,2),'DisplayName',['a=',num2str(a(j))])
    end
    
    title([TitleLine,num2str(u(i)*100),'%'])
    xlabel('Time [s]')
    ylabel('Element Tortinal Moment [kNm]')        
    legend('Location','best')
    hold off
end


% Ploting max curvature vs. Time
for i=1:length(u)
    
    figure
    hold on
    for j=1:length(a)
        ModelName=[NameModel0,num2str(a(j)*10),'u',num2str(u(i)*100)];
        [Y,~]=readGL(ElementN,endT,[ModelName,'_y.mpf']);
        [Z,t]=readGL(ElementN,endT,[ModelName,'_z.mpf']);
        
        % Calculating total curvature
        S=zeros(size(Y));
        S(:,1)=Y(:,1);
        for k=1:length(t)
            S(:,k+1)=sqrt(Z(:,k+1).^2+Y(:,k+1).^2);
        end
        
        % Calculating maximum total curvatur
        [v,sN]=min(abs(S(:,1)-2610));
        Cmax=max(S(1:sN,2:end));

        % Ploting max curvature vs. Time
        plot(t,Cmax,'-o','DisplayName',['a=',num2str(a(j))]')
    end
    
    plot([0,endT],[C,C],'--','DisplayName','Buckling curvature')
    plot([0,endT],[K,K],'--','DisplayName','Maximum allowable curvature')
    title([TitleLine,num2str(u(i)*100),'%'])
    xlabel('Time [s]')
    ylabel('Total maximum curvature [1/m]')
    legend('Location','best')
    hold off
end






